=========================
 OpenStack Project Teams
=========================

Here is the list of all official OpenStack project teams, which produce the
various deliverables of the OpenStack family (or help other teams achieve
that mission). All official OpenStack project teams are under the OpenStack
Technical Committee oversight.

Project teams interested in joining as an official project should read the
:doc:`../new-projects-requirements`, and apply by proposing the
corresponding change to the `reference/projects.yaml` file in the
`openstack/governance` repository.

.. _projects:

Projects
--------

.. toctree::
   :glob:
   :titlesonly:

   *
